==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterClaimSpecBuilder extends ClusterClaimSpecFluentImpl<ClusterClaimSpecBuilder> implements VisitableBuilder<ClusterClaimSpec,ClusterClaimSpecBuilder>{
  public ClusterClaimSpecBuilder() {
    this(false);
  }
  public ClusterClaimSpecBuilder(Boolean validationEnabled) {
    this(new ClusterClaimSpec(), validationEnabled);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterClaimSpec(), validationEnabled);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent,ClusterClaimSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent,ClusterClaimSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withClusterPoolName(instance.getClusterPoolName());
      fluent.withLifetime(instance.getLifetime());
      fluent.withNamespace(instance.getNamespace());
      fluent.withSubjects(instance.getSubjects());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpec instance) {
    this(instance,false);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withClusterPoolName(instance.getClusterPoolName());
      this.withLifetime(instance.getLifetime());
      this.withNamespace(instance.getNamespace());
      this.withSubjects(instance.getSubjects());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterClaimSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterClaimSpec build() {
    ClusterClaimSpec buildable = new ClusterClaimSpec(fluent.getClusterPoolName(),fluent.getLifetime(),fluent.getNamespace(),fluent.getSubjects());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterClaimSpecBuilder extends ClusterClaimSpecFluent<ClusterClaimSpecBuilder> implements VisitableBuilder<ClusterClaimSpec,ClusterClaimSpecBuilder>{
  public ClusterClaimSpecBuilder() {
    this(false);
  }
  public ClusterClaimSpecBuilder(Boolean validationEnabled) {
    this(new ClusterClaimSpec(), validationEnabled);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterClaimSpec(), validationEnabled);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent,ClusterClaimSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpecFluent<?> fluent,ClusterClaimSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterClaimSpec());

    if (instance != null) {
      fluent.withClusterPoolName(instance.getClusterPoolName());
      fluent.withLifetime(instance.getLifetime());
      fluent.withNamespace(instance.getNamespace());
      fluent.withSubjects(instance.getSubjects());
      fluent.withClusterPoolName(instance.getClusterPoolName());
      fluent.withLifetime(instance.getLifetime());
      fluent.withNamespace(instance.getNamespace());
      fluent.withSubjects(instance.getSubjects());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpec instance) {
    this(instance,false);
  }
  public ClusterClaimSpecBuilder(ClusterClaimSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterClaimSpec());

    if (instance != null) {
      this.withClusterPoolName(instance.getClusterPoolName());
      this.withLifetime(instance.getLifetime());
      this.withNamespace(instance.getNamespace());
      this.withSubjects(instance.getSubjects());
      this.withClusterPoolName(instance.getClusterPoolName());
      this.withLifetime(instance.getLifetime());
      this.withNamespace(instance.getNamespace());
      this.withSubjects(instance.getSubjects());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterClaimSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterClaimSpec build() {
    ClusterClaimSpec buildable = new ClusterClaimSpec(fluent.getClusterPoolName(),fluent.getLifetime(),fluent.getNamespace(),fluent.getSubjects());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
